#!/bin/bash

echo === Delete installed Zytronic Components ===============

# This file is run as a part of the generalized installer
# for the Zytronic Touchscreen Linux Drivers

# It deletes components installed to support the ZXY100
# family of touchscreen controllers.

##### Verify root privileges
USER_ID=`id -u`
if [ ${USER_ID} != 0 ]; then
echo === User must be root. =================================
        echo -e "try\n $ su -\nor\n $ sudo $0"
        exit 1
fi

##### stop the rebinder service
if [ -e /etc/init.d/zxy_device_rebind_init ]
then
	/etc/init.d/zxy_device_rebind_init uninstall
fi

##### Remove the module for the auto-load list

#- Debian, etc.
if [ -e /etc/modules ]; then
	chmod 777 /etc/modules
	sed -i '/zxy/ d' /etc/modules
	chmod 644 /etc/modules
fi

##### remove the kernel modules

modprobe -r zxy100_usb 2> /dev/null
modprobe -r zxy100_serial 2> /dev/null
modprobe -r zxy100_common 2> /dev/null

modprobe -r zxy200_usb 2> /dev/null
modprobe -r zxy200_common 2> /dev/null

modprobe -r zxy_mt_usb 2> /dev/null
modprobe -r zxy_mt_common 2> /dev/null


# set to 1 to confirm each file-set removal
# CONFIRM=0
# [ ! -z $1 ] && CONFIRM=$1 # allow command line override

SRCSO_DIR=/usr/src/modules/zxy100-modules
SRCSU_DIR=/usr/src/modules/zytronic-driver
SRCS1_DIR=/usr/src/modules/zytronic100
SRCS2_DIR=/usr/src/modules/zytronic200
SRCSM_DIR=/usr/src/modules/zytronic_mt

INIT_DIR=/etc/init.d
SBIN_DIR=/usr/sbin
BIN_DIR=/usr/bin
TEMP_TXT=./temp.txt

echo --- Remove the kernel module files ---

for dir in $SRCSO_DIR $SRCSU_DIR $SRCS1_DIR $SRCS2_DIR $SRCSM_DIR
do
	if [ -e $dir ]; then
		pushd $dir > /dev/null
		echo --- `pwd`
		echo -e "\n   The depmod command may take some time ...\n"
		make clean
		popd > /dev/null

		# Remove the sources dir
		rm -rf $dir
	fi
done

##### remove the service init sym-links
find /etc/ -name "*zxy*rebind_init" | xargs rm -f 

##### remove the service init script
rm -f $INIT_DIR/zxy*rebind_init

##### remove the rebind script
rm -f $SBIN_DIR/zxy*rebind

##### 
rm -f $BIN_DIR/ZyConfig

echo =========================================== All Done ===
exit 0
